@@ -1,20 +1,23 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for cloudfront service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.cloudfront import CloudFrontClient
-
-    session = boto3.Session()
+    from mypy_boto3_cloudfront import CloudFrontClient
 
     client: CloudFrontClient = boto3.client("cloudfront")
-    session_client: CloudFrontClient = session.client("cloudfront")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+from botocore.waiter import Waiter as Boto3Waiter
+
 from mypy_boto3_cloudfront.paginator import (
     ListCloudFrontOriginAccessIdentitiesPaginator,
     ListDistributionsPaginator,
@@ -173,107 +176,107 @@ class Exceptions:
 
 class CloudFrontClient:
     """
-    [CloudFront.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client)
+    [CloudFront.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.can_paginate)
         """
 
     def create_cloud_front_origin_access_identity(
-        self, CloudFrontOriginAccessIdentityConfig: CloudFrontOriginAccessIdentityConfigTypeDef
+        self, CloudFrontOriginAccessIdentityConfig: "CloudFrontOriginAccessIdentityConfigTypeDef"
     ) -> CreateCloudFrontOriginAccessIdentityResultTypeDef:
         """
-        [Client.create_cloud_front_origin_access_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.create_cloud_front_origin_access_identity)
+        [Client.create_cloud_front_origin_access_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.create_cloud_front_origin_access_identity)
         """
 
     def create_distribution(
-        self, DistributionConfig: DistributionConfigTypeDef
+        self, DistributionConfig: "DistributionConfigTypeDef"
     ) -> CreateDistributionResultTypeDef:
         """
-        [Client.create_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.create_distribution)
+        [Client.create_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.create_distribution)
         """
 
     def create_distribution_with_tags(
         self, DistributionConfigWithTags: DistributionConfigWithTagsTypeDef
     ) -> CreateDistributionWithTagsResultTypeDef:
         """
-        [Client.create_distribution_with_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.create_distribution_with_tags)
+        [Client.create_distribution_with_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.create_distribution_with_tags)
         """
 
     def create_field_level_encryption_config(
-        self, FieldLevelEncryptionConfig: FieldLevelEncryptionConfigTypeDef
+        self, FieldLevelEncryptionConfig: "FieldLevelEncryptionConfigTypeDef"
     ) -> CreateFieldLevelEncryptionConfigResultTypeDef:
         """
-        [Client.create_field_level_encryption_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.create_field_level_encryption_config)
+        [Client.create_field_level_encryption_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.create_field_level_encryption_config)
         """
 
     def create_field_level_encryption_profile(
-        self, FieldLevelEncryptionProfileConfig: FieldLevelEncryptionProfileConfigTypeDef
+        self, FieldLevelEncryptionProfileConfig: "FieldLevelEncryptionProfileConfigTypeDef"
     ) -> CreateFieldLevelEncryptionProfileResultTypeDef:
         """
-        [Client.create_field_level_encryption_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.create_field_level_encryption_profile)
+        [Client.create_field_level_encryption_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.create_field_level_encryption_profile)
         """
 
     def create_invalidation(
-        self, DistributionId: str, InvalidationBatch: InvalidationBatchTypeDef
+        self, DistributionId: str, InvalidationBatch: "InvalidationBatchTypeDef"
     ) -> CreateInvalidationResultTypeDef:
         """
-        [Client.create_invalidation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.create_invalidation)
+        [Client.create_invalidation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.create_invalidation)
         """
 
     def create_public_key(
-        self, PublicKeyConfig: PublicKeyConfigTypeDef
+        self, PublicKeyConfig: "PublicKeyConfigTypeDef"
     ) -> CreatePublicKeyResultTypeDef:
         """
-        [Client.create_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.create_public_key)
+        [Client.create_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.create_public_key)
         """
 
     def create_streaming_distribution(
-        self, StreamingDistributionConfig: StreamingDistributionConfigTypeDef
+        self, StreamingDistributionConfig: "StreamingDistributionConfigTypeDef"
     ) -> CreateStreamingDistributionResultTypeDef:
         """
-        [Client.create_streaming_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.create_streaming_distribution)
+        [Client.create_streaming_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.create_streaming_distribution)
         """
 
     def create_streaming_distribution_with_tags(
         self, StreamingDistributionConfigWithTags: StreamingDistributionConfigWithTagsTypeDef
     ) -> CreateStreamingDistributionWithTagsResultTypeDef:
         """
-        [Client.create_streaming_distribution_with_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.create_streaming_distribution_with_tags)
+        [Client.create_streaming_distribution_with_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.create_streaming_distribution_with_tags)
         """
 
     def delete_cloud_front_origin_access_identity(self, Id: str, IfMatch: str = None) -> None:
         """
-        [Client.delete_cloud_front_origin_access_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.delete_cloud_front_origin_access_identity)
+        [Client.delete_cloud_front_origin_access_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.delete_cloud_front_origin_access_identity)
         """
 
     def delete_distribution(self, Id: str, IfMatch: str = None) -> None:
         """
-        [Client.delete_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.delete_distribution)
+        [Client.delete_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.delete_distribution)
         """
 
     def delete_field_level_encryption_config(self, Id: str, IfMatch: str = None) -> None:
         """
-        [Client.delete_field_level_encryption_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.delete_field_level_encryption_config)
+        [Client.delete_field_level_encryption_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.delete_field_level_encryption_config)
         """
 
     def delete_field_level_encryption_profile(self, Id: str, IfMatch: str = None) -> None:
         """
-        [Client.delete_field_level_encryption_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.delete_field_level_encryption_profile)
+        [Client.delete_field_level_encryption_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.delete_field_level_encryption_profile)
         """
 
     def delete_public_key(self, Id: str, IfMatch: str = None) -> None:
         """
-        [Client.delete_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.delete_public_key)
+        [Client.delete_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.delete_public_key)
         """
 
     def delete_streaming_distribution(self, Id: str, IfMatch: str = None) -> None:
         """
-        [Client.delete_streaming_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.delete_streaming_distribution)
+        [Client.delete_streaming_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.delete_streaming_distribution)
         """
 
     def generate_presigned_url(
@@ -284,209 +287,209 @@ class CloudFrontClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.generate_presigned_url)
         """
 
     def get_cloud_front_origin_access_identity(
         self, Id: str
     ) -> GetCloudFrontOriginAccessIdentityResultTypeDef:
         """
-        [Client.get_cloud_front_origin_access_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_cloud_front_origin_access_identity)
+        [Client.get_cloud_front_origin_access_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_cloud_front_origin_access_identity)
         """
 
     def get_cloud_front_origin_access_identity_config(
         self, Id: str
     ) -> GetCloudFrontOriginAccessIdentityConfigResultTypeDef:
         """
-        [Client.get_cloud_front_origin_access_identity_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_cloud_front_origin_access_identity_config)
+        [Client.get_cloud_front_origin_access_identity_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_cloud_front_origin_access_identity_config)
         """
 
     def get_distribution(self, Id: str) -> GetDistributionResultTypeDef:
         """
-        [Client.get_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_distribution)
+        [Client.get_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_distribution)
         """
 
     def get_distribution_config(self, Id: str) -> GetDistributionConfigResultTypeDef:
         """
-        [Client.get_distribution_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_distribution_config)
+        [Client.get_distribution_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_distribution_config)
         """
 
     def get_field_level_encryption(self, Id: str) -> GetFieldLevelEncryptionResultTypeDef:
         """
-        [Client.get_field_level_encryption documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_field_level_encryption)
+        [Client.get_field_level_encryption documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_field_level_encryption)
         """
 
     def get_field_level_encryption_config(
         self, Id: str
     ) -> GetFieldLevelEncryptionConfigResultTypeDef:
         """
-        [Client.get_field_level_encryption_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_field_level_encryption_config)
+        [Client.get_field_level_encryption_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_field_level_encryption_config)
         """
 
     def get_field_level_encryption_profile(
         self, Id: str
     ) -> GetFieldLevelEncryptionProfileResultTypeDef:
         """
-        [Client.get_field_level_encryption_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_field_level_encryption_profile)
+        [Client.get_field_level_encryption_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_field_level_encryption_profile)
         """
 
     def get_field_level_encryption_profile_config(
         self, Id: str
     ) -> GetFieldLevelEncryptionProfileConfigResultTypeDef:
         """
-        [Client.get_field_level_encryption_profile_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_field_level_encryption_profile_config)
+        [Client.get_field_level_encryption_profile_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_field_level_encryption_profile_config)
         """
 
     def get_invalidation(self, DistributionId: str, Id: str) -> GetInvalidationResultTypeDef:
         """
-        [Client.get_invalidation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_invalidation)
+        [Client.get_invalidation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_invalidation)
         """
 
     def get_public_key(self, Id: str) -> GetPublicKeyResultTypeDef:
         """
-        [Client.get_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_public_key)
+        [Client.get_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_public_key)
         """
 
     def get_public_key_config(self, Id: str) -> GetPublicKeyConfigResultTypeDef:
         """
-        [Client.get_public_key_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_public_key_config)
+        [Client.get_public_key_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_public_key_config)
         """
 
     def get_streaming_distribution(self, Id: str) -> GetStreamingDistributionResultTypeDef:
         """
-        [Client.get_streaming_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_streaming_distribution)
+        [Client.get_streaming_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_streaming_distribution)
         """
 
     def get_streaming_distribution_config(
         self, Id: str
     ) -> GetStreamingDistributionConfigResultTypeDef:
         """
-        [Client.get_streaming_distribution_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.get_streaming_distribution_config)
+        [Client.get_streaming_distribution_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.get_streaming_distribution_config)
         """
 
     def list_cloud_front_origin_access_identities(
         self, Marker: str = None, MaxItems: str = None
     ) -> ListCloudFrontOriginAccessIdentitiesResultTypeDef:
         """
-        [Client.list_cloud_front_origin_access_identities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.list_cloud_front_origin_access_identities)
+        [Client.list_cloud_front_origin_access_identities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.list_cloud_front_origin_access_identities)
         """
 
     def list_distributions(
         self, Marker: str = None, MaxItems: str = None
     ) -> ListDistributionsResultTypeDef:
         """
-        [Client.list_distributions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.list_distributions)
+        [Client.list_distributions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.list_distributions)
         """
 
     def list_distributions_by_web_acl_id(
         self, WebACLId: str, Marker: str = None, MaxItems: str = None
     ) -> ListDistributionsByWebACLIdResultTypeDef:
         """
-        [Client.list_distributions_by_web_acl_id documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.list_distributions_by_web_acl_id)
+        [Client.list_distributions_by_web_acl_id documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.list_distributions_by_web_acl_id)
         """
 
     def list_field_level_encryption_configs(
         self, Marker: str = None, MaxItems: str = None
     ) -> ListFieldLevelEncryptionConfigsResultTypeDef:
         """
-        [Client.list_field_level_encryption_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.list_field_level_encryption_configs)
+        [Client.list_field_level_encryption_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.list_field_level_encryption_configs)
         """
 
     def list_field_level_encryption_profiles(
         self, Marker: str = None, MaxItems: str = None
     ) -> ListFieldLevelEncryptionProfilesResultTypeDef:
         """
-        [Client.list_field_level_encryption_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.list_field_level_encryption_profiles)
+        [Client.list_field_level_encryption_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.list_field_level_encryption_profiles)
         """
 
     def list_invalidations(
         self, DistributionId: str, Marker: str = None, MaxItems: str = None
     ) -> ListInvalidationsResultTypeDef:
         """
-        [Client.list_invalidations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.list_invalidations)
+        [Client.list_invalidations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.list_invalidations)
         """
 
     def list_public_keys(
         self, Marker: str = None, MaxItems: str = None
     ) -> ListPublicKeysResultTypeDef:
         """
-        [Client.list_public_keys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.list_public_keys)
+        [Client.list_public_keys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.list_public_keys)
         """
 
     def list_streaming_distributions(
         self, Marker: str = None, MaxItems: str = None
     ) -> ListStreamingDistributionsResultTypeDef:
         """
-        [Client.list_streaming_distributions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.list_streaming_distributions)
+        [Client.list_streaming_distributions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.list_streaming_distributions)
         """
 
     def list_tags_for_resource(self, Resource: str) -> ListTagsForResourceResultTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.list_tags_for_resource)
         """
 
-    def tag_resource(self, Resource: str, Tags: TagsTypeDef) -> None:
+    def tag_resource(self, Resource: str, Tags: "TagsTypeDef") -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.tag_resource)
         """
 
     def untag_resource(self, Resource: str, TagKeys: TagKeysTypeDef) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.untag_resource)
         """
 
     def update_cloud_front_origin_access_identity(
         self,
-        CloudFrontOriginAccessIdentityConfig: CloudFrontOriginAccessIdentityConfigTypeDef,
+        CloudFrontOriginAccessIdentityConfig: "CloudFrontOriginAccessIdentityConfigTypeDef",
         Id: str,
         IfMatch: str = None,
     ) -> UpdateCloudFrontOriginAccessIdentityResultTypeDef:
         """
-        [Client.update_cloud_front_origin_access_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.update_cloud_front_origin_access_identity)
+        [Client.update_cloud_front_origin_access_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.update_cloud_front_origin_access_identity)
         """
 
     def update_distribution(
-        self, DistributionConfig: DistributionConfigTypeDef, Id: str, IfMatch: str = None
+        self, DistributionConfig: "DistributionConfigTypeDef", Id: str, IfMatch: str = None
     ) -> UpdateDistributionResultTypeDef:
         """
-        [Client.update_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.update_distribution)
+        [Client.update_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.update_distribution)
         """
 
     def update_field_level_encryption_config(
         self,
-        FieldLevelEncryptionConfig: FieldLevelEncryptionConfigTypeDef,
+        FieldLevelEncryptionConfig: "FieldLevelEncryptionConfigTypeDef",
         Id: str,
         IfMatch: str = None,
     ) -> UpdateFieldLevelEncryptionConfigResultTypeDef:
         """
-        [Client.update_field_level_encryption_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.update_field_level_encryption_config)
+        [Client.update_field_level_encryption_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.update_field_level_encryption_config)
         """
 
     def update_field_level_encryption_profile(
         self,
-        FieldLevelEncryptionProfileConfig: FieldLevelEncryptionProfileConfigTypeDef,
+        FieldLevelEncryptionProfileConfig: "FieldLevelEncryptionProfileConfigTypeDef",
         Id: str,
         IfMatch: str = None,
     ) -> UpdateFieldLevelEncryptionProfileResultTypeDef:
         """
-        [Client.update_field_level_encryption_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.update_field_level_encryption_profile)
+        [Client.update_field_level_encryption_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.update_field_level_encryption_profile)
         """
 
     def update_public_key(
-        self, PublicKeyConfig: PublicKeyConfigTypeDef, Id: str, IfMatch: str = None
+        self, PublicKeyConfig: "PublicKeyConfigTypeDef", Id: str, IfMatch: str = None
     ) -> UpdatePublicKeyResultTypeDef:
         """
-        [Client.update_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.update_public_key)
+        [Client.update_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.update_public_key)
         """
 
     def update_streaming_distribution(
         self,
-        StreamingDistributionConfig: StreamingDistributionConfigTypeDef,
+        StreamingDistributionConfig: "StreamingDistributionConfigTypeDef",
         Id: str,
         IfMatch: str = None,
     ) -> UpdateStreamingDistributionResultTypeDef:
         """
-        [Client.update_streaming_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Client.update_streaming_distribution)
+        [Client.update_streaming_distribution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Client.update_streaming_distribution)
         """
 
     @overload
@@ -494,7 +497,7 @@ class CloudFrontClient:
         self, operation_name: Literal["list_cloud_front_origin_access_identities"]
     ) -> ListCloudFrontOriginAccessIdentitiesPaginator:
         """
-        [Paginator.ListCloudFrontOriginAccessIdentities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Paginator.ListCloudFrontOriginAccessIdentities)
+        [Paginator.ListCloudFrontOriginAccessIdentities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Paginator.ListCloudFrontOriginAccessIdentities)
         """
 
     @overload
@@ -502,7 +505,7 @@ class CloudFrontClient:
         self, operation_name: Literal["list_distributions"]
     ) -> ListDistributionsPaginator:
         """
-        [Paginator.ListDistributions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Paginator.ListDistributions)
+        [Paginator.ListDistributions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Paginator.ListDistributions)
         """
 
     @overload
@@ -510,7 +513,7 @@ class CloudFrontClient:
         self, operation_name: Literal["list_invalidations"]
     ) -> ListInvalidationsPaginator:
         """
-        [Paginator.ListInvalidations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Paginator.ListInvalidations)
+        [Paginator.ListInvalidations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Paginator.ListInvalidations)
         """
 
     @overload
@@ -518,15 +521,18 @@ class CloudFrontClient:
         self, operation_name: Literal["list_streaming_distributions"]
     ) -> ListStreamingDistributionsPaginator:
         """
-        [Paginator.ListStreamingDistributions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Paginator.ListStreamingDistributions)
+        [Paginator.ListStreamingDistributions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Paginator.ListStreamingDistributions)
         """
 
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
+
     @overload
     def get_waiter(
         self, waiter_name: Literal["distribution_deployed"]
     ) -> DistributionDeployedWaiter:
         """
-        [Waiter.DistributionDeployed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Waiter.DistributionDeployed)
+        [Waiter.DistributionDeployed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Waiter.DistributionDeployed)
         """
 
     @overload
@@ -534,7 +540,7 @@ class CloudFrontClient:
         self, waiter_name: Literal["invalidation_completed"]
     ) -> InvalidationCompletedWaiter:
         """
-        [Waiter.InvalidationCompleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Waiter.InvalidationCompleted)
+        [Waiter.InvalidationCompleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Waiter.InvalidationCompleted)
         """
 
     @overload
@@ -542,5 +548,8 @@ class CloudFrontClient:
         self, waiter_name: Literal["streaming_distribution_deployed"]
     ) -> StreamingDistributionDeployedWaiter:
         """
-        [Waiter.StreamingDistributionDeployed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Waiter.StreamingDistributionDeployed)
+        [Waiter.StreamingDistributionDeployed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Waiter.StreamingDistributionDeployed)
         """
+
+    def get_waiter(self, waiter_name: str) -> Boto3Waiter:
+        pass
