@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 """
 Main interface for cloudfront service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.cloudfront import (
+
+    from mypy_boto3_cloudfront import CloudFrontClient
+    from mypy_boto3_cloudfront.waiter import (
         DistributionDeployedWaiter,
         InvalidationCompletedWaiter,
         StreamingDistributionDeployedWaiter,
@@ -15,12 +19,11 @@ Usage::
     distribution_deployed_waiter: DistributionDeployedWaiter = client.get_waiter("distribution_deployed")
     invalidation_completed_waiter: InvalidationCompletedWaiter = client.get_waiter("invalidation_completed")
     streaming_distribution_deployed_waiter: StreamingDistributionDeployedWaiter = client.get_waiter("streaming_distribution_deployed")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import TYPE_CHECKING
 from botocore.waiter import Waiter as Boto3Waiter
-from mypy_boto3_cloudfront.type_defs import WaiterConfigTypeDef
 
+from mypy_boto3_cloudfront.type_defs import WaiterConfigTypeDef
 
 __all__ = (
     "DistributionDeployedWaiter",
@@ -31,32 +34,32 @@ __all__ = (
 
 class DistributionDeployedWaiter(Boto3Waiter):
     """
-    [Waiter.DistributionDeployed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Waiter.DistributionDeployed)
+    [Waiter.DistributionDeployed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Waiter.DistributionDeployed)
     """
 
     def wait(self, Id: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
         """
-        [DistributionDeployed.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Waiter.DistributionDeployed.wait)
+        [DistributionDeployed.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Waiter.DistributionDeployed.wait)
         """
 
 
 class InvalidationCompletedWaiter(Boto3Waiter):
     """
-    [Waiter.InvalidationCompleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Waiter.InvalidationCompleted)
+    [Waiter.InvalidationCompleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Waiter.InvalidationCompleted)
     """
 
     def wait(self, DistributionId: str, Id: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
         """
-        [InvalidationCompleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Waiter.InvalidationCompleted.wait)
+        [InvalidationCompleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Waiter.InvalidationCompleted.wait)
         """
 
 
 class StreamingDistributionDeployedWaiter(Boto3Waiter):
     """
-    [Waiter.StreamingDistributionDeployed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Waiter.StreamingDistributionDeployed)
+    [Waiter.StreamingDistributionDeployed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Waiter.StreamingDistributionDeployed)
     """
 
     def wait(self, Id: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
         """
-        [StreamingDistributionDeployed.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/cloudfront.html#CloudFront.Waiter.StreamingDistributionDeployed.wait)
+        [StreamingDistributionDeployed.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.2/reference/services/cloudfront.html#CloudFront.Waiter.StreamingDistributionDeployed.wait)
         """
